Module color

Module color 

Color types and ANSI escape-code generation used by the styling API.

Structs

CustomColor
A truecolor value specified by red, green, and blue byte components.

Enums

Color
A color used for foreground and background text styling.