Color

Enum Color 

pub enum Color {
Show 18 variants Black, Red, Green, Yellow, Blue, Magenta, Cyan, White, BrightBlack, BrightRed, BrightGreen, BrightYellow, BrightBlue, BrightMagenta, BrightCyan, BrightWhite, AnsiColor(u8), TrueColor { r: u8, g: u8, b: u8, },
}
A color used for foreground and background text styling.

Named variants map to the standard 16 ANSI terminal colors. AnsiColor selects one of the 256 extended palette entries. TrueColor accepts arbitrary 24-bit RGB values when the terminal supports it.

Variants



Black

Standard black (ANSI 30 / 40).



Red

Standard red (ANSI 31 / 41).



Green

Standard green (ANSI 32 / 42).



Yellow

Standard yellow (ANSI 33 / 43).



Blue

Standard blue (ANSI 34 / 44).



Magenta

Standard magenta (ANSI 35 / 45).



Cyan

Standard cyan (ANSI 36 / 46).



White

Standard white (ANSI 37 / 47).



BrightBlack

Bright black / dark gray (ANSI 90 / 100).



BrightRed

Bright red (ANSI 91 / 101).



BrightGreen

Bright green (ANSI 92 / 102).



BrightYellow

Bright yellow (ANSI 93 / 103).



BrightBlue

Bright blue (ANSI 94 / 104).



BrightMagenta

Bright magenta (ANSI 95 / 105).



BrightCyan

Bright cyan (ANSI 96 / 106).



BrightWhite

Bright white (ANSI 97 / 107).



AnsiColor(u8)

One of the 256-color extended palette entries (\x1b[38;5;n).



TrueColor

A 24-bit truecolor value (\x1b[38;2;r;g;b).

Fields

r: u8

Red component (0–255).

g: u8

Green component (0–255).

b: u8

Blue component (0–255).