pub enum Align {
Center,
Left,
Right,
}Expand description
Alignment options for any content supporting alignment.
Examples
use tiny_table::{Align, Table};
let mut table = Table::new();
table.add_section("Team").align(Align::Right);Variants
Center
Center the content within the available width.
Left
Place the content toward the left side of the available width.
Right
Place the content toward the right side of the available width.