SectionStyle

Struct SectionStyle 

pub struct SectionStyle {
    pub horiz: &'static str,
    pub mid_left: &'static str,
    pub mid_right: &'static str,
    pub mid_joint: &'static str,
}
Characters used to overwrite section and separator styles.

Fields

horiz: &'static str

Horizontal border character.

mid_left: &'static str

Left border character for section separators and middle rules.

mid_right: &'static str

Right border character for section separators and middle rules.

mid_joint: &'static str

Joint character for interior separators.

Implementations

Source

impl SectionStyle

pub fn unicode() -> Self

Return the default Unicode border style for sections and separators.

Examples found in repository?
examples/styled.rs (line 18)
3fn main() {
4    let mut table = Table::with_columns(vec![
5        Column::new("Name").bright_cyan().bold().width(0.3),
6        Column::new("Role").width(0.4).truncate(Trunc::Middle),
7        Column::new("Status").bright_yellow().bold().width(0.3),
8    ])
9    .with_section_style(SectionStyle {
10        horiz: "═",
11        mid_left: "╞",
12        mid_right: "╡",
13        mid_joint: "╪",
14    })
15    .with_separator_style(SectionStyle {
16        horiz: "╌",
17        mid_joint: "│",
18        ..SectionStyle::unicode()
19    });
20
21    table.add_section("Team").align(Align::Center);
22    table.add_row(vec![
23        Cell::new("Ada Lovelace"),
24        Cell::new("Principal Engineer"),
25        Cell::new("Active").bright_green(),
26    ]);
27
28    table.add_separator();
29    table.add_row(vec![
30        Cell::new("Bob"),
31        Cell::new("Support"),
32        Cell::new("Away"),
33    ]);
34
35    println!("{}", table);
36}
pub fn from_table_style(table_style: TableStyle) -> Self

Convert a TableStyle into a SectionStyle by taking the relevant fields