Module style

Module style 

Style actions and macros for applying colors and formatting to cells and columns.

Enums

StyleAction
A styling action to apply to text (color, formatting, etc.).

Functions

apply_style_actions
Apply a sequence of style actions to content, wrapping it in ANSI escape codes.