Color types and ANSI escape-code generation used by the styling API.
Structs
- Custom
Color - A truecolor value specified by red, green, and blue byte components.
Enums
- Color
- A color used for foreground and background text styling.
Color types and ANSI escape-code generation used by the styling API.