pub enum Trunc {
End,
Start,
Middle,
NewLine,
}Expand description
How to handle content that does not fit inside the available column width.
Truncation is applied after the column width is resolved. If you need the
full content to remain visible, use Trunc::NewLine to wrap onto more
lines instead of clipping the text.
Examples
use tiny_table::{Cell, Trunc};
let cell = Cell::new("abcdefghij").truncate(Trunc::Middle);Variants
End
Keep the beginning of the text and add an ellipsis at the end.
Start
Keep the end of the text and add an ellipsis at the start.
Middle
Keep the start and end of the text with an ellipsis in the middle.
NewLine
Wrap onto multiple lines instead of truncating.